---
name: New Score or Metric
about: Suggest a new score or metric which could be added to the repository

---

**I would like the following metric or statistical test to be considered for addition to the `scores` repository**  
Please briefly describe the metric or statistical test and why you think it would be useful.

**Please provide a reference that describes the metric or statistical test**  
Note: if the reference includes multiple versions of the metric, and you are interested in a specific version, please note that (e.g. specify which theorem or corollary). 

**(Please delete this section if not applicable) I intend to submit a pull request for the new metric or statistical test**
- [ ] Please read the [Contributing Guide,](https://scores.readthedocs.io/en/develop/contributing.html#contributing-guide) in particular the [Development Process for a New Score or Metric](https://scores.readthedocs.io/en/develop/contributing.html#development-process-for-a-new-score-or-metric) section
- [ ] Please read the [pull request checklist](https://github.com/nci/scores/blob/develop/.github/pull_request_template.md)
- [ ] I understand that, due to practical constraints, it may not always be possible for a metric or statistical test to be added
